==> guikachu-1.1.3.tar.gz: guikachu-1.1.3/src/form-editor/scrollbar.h <==
//$Id: scrollbar.h,v 1.11 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_SCROLLBAR_H
#define GUIKACHU_FORM_EDITOR_SCROLLBAR_H

namespace Guikachu
{
    namespace Widgets
    {
	class ScrollBar;
    }
}

#include "widget.h"
#include "resizeable.h"

#include "scrollbar-prop.h"

namespace Guikachu
{
    namespace Widgets
    {
	class ScrollBar: public Widget
	{
	    GUI::FormEditor::ScrollBarProperties *editor;

	    SigC::Signal0<void> manual_width_changed;
	    
	public:
	    ScrollBar (Resources::Form   *owner,
		       const std::string &id);
	    virtual ~ScrollBar ();
	    
	    virtual Type get_type () const { return WIDGET_SCROLLBAR; };
	    
	    virtual Gtk::Widget                       *create_editor ();
	    virtual GUI::FormEditor::WidgetCanvasItem *create_canvas_item (Gnome::CanvasGroup *parent_group);

	    Property<bool> usable;
	    Property<int>  min_value, max_value, value, page_size;

	    Property<int>  width;
	    Property<bool> manual_width;
	    Property<int>  height;
	    
	    int get_display_width () const;

	protected:
	    int get_auto_width () const;

	private:
	    void manual_width_cb ();
	    
	private:
	    // Persistance
	    virtual bool load (StorageNode &node);
	    virtual void save (StorageNode &node) const;
	    virtual void save_rcp (std::ostream &ostr) const;

	private:
	    void update ();
	};
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_SCROLLBAR_H */

==> guikachu-1.1.6.tar.gz: guikachu-1.1.6/src/form-editor/scrollbar.h <==
//$Id: scrollbar.h,v 1.12 2002/01/30 17:33:10 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_SCROLLBAR_H
#define GUIKACHU_FORM_EDITOR_SCROLLBAR_H

namespace Guikachu
{
    namespace Widgets
    {
	class ScrollBar;
    }
}

#include "widget.h"
#include "auto-resizeable.h"

#include "scrollbar-prop.h"

namespace Guikachu
{
    namespace Widgets
    {
	class ScrollBar: public Widget,
			 public AutoWidth
	{
	    GUI::FormEditor::ScrollBarProperties *editor;

	public:
	    ScrollBar (Resources::Form   *owner,
		       const std::string &id);
	    virtual ~ScrollBar ();
	    
	    virtual Type get_type () const { return WIDGET_SCROLLBAR; };
	    
	    virtual Gtk::Widget                       *create_editor ();
	    virtual GUI::FormEditor::WidgetCanvasItem *create_canvas_item (Gnome::CanvasGroup *parent_group);

	    Property<bool> usable;
	    Property<int>  min_value, max_value, value, page_size;
	    
	protected:
	    int get_auto_width () const;

	private:
	    // Persistance
	    virtual bool load (StorageNode &node);
	    virtual void save (StorageNode &node) const;
	    virtual void save_rcp (std::ostream &ostr) const;

	private:
	    void update ();
	};
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_SCROLLBAR_H */
